import{a as e,A as t,B as s}from"./Text.b4fa08c4.js";import{A as o}from"./Link.0df5f530.js";import{a as r,A as i}from"./Title.50fff1e9.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="ca6b1691-86b3-45d6-a8b8-4c345e63ec71",n._sentryDebugIdIdentifier="sentry-dbid-ca6b1691-86b3-45d6-a8b8-4c345e63ec71")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,i),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.61a3d490.js.map
