import{C as t,E as i,K as d,a as c,M as l,c as y,P as f,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.16d31c20.js";import"./outputWidgets.517466a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="96955018-ba03-4a2a-991d-a458c8933954",e._sentryDebugIdIdentifier="sentry-dbid-96955018-ba03-4a2a-991d-a458c8933954")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,c as KeyMod,l as MarkerSeverity,y as MarkerTag,f as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.5309c00a.js.map
