import{Q as c}from"./outputWidgets.517466a4.js";import{c as i,d}from"./index.43f8c1fe.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="01398573-b20f-4ade-aeb9-f79a3a8c7837",e._sentryDebugIdIdentifier="sentry-dbid-01398573-b20f-4ade-aeb9-f79a3a8c7837")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),y=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.f26e4e52.js.map
