var o=Object.defineProperty;var i=(t,e,r)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:r}):t[e]=r;var a=(t,e,r)=>(i(t,typeof e!="symbol"?e+"":e,r),r);import{g as c,h as f,_ as u}from"./outputWidgets.517466a4.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7fe23484-1e93-4105-bbc5-1278c9245b7b",t._sentryDebugIdIdentifier="sentry-dbid-7fe23484-1e93-4105-bbc5-1278c9245b7b")}catch{}})();const d=[{path:"/:path(.*)*",name:"player",component:()=>u(()=>import("./Player.ecae335c.js"),["assets/Player.ecae335c.js","assets/FormRunner.2fa82366.js","assets/outputWidgets.517466a4.js","assets/outputWidgets.bd537527.css","assets/url.f9726388.js","assets/storage.a7faa4ce.js","assets/pubsub.1c68a664.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.18ac3d6d.js","assets/CircularLoading.c3f6250e.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.cd625dbd.js","assets/PlayerNavbar.ead94b03.css","assets/ActionButton.ea0059c2.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.b55041e8.js","assets/WidgetsFrame.97ae601d.css","assets/index.0b6667c1.js","assets/Card.5b543243.js","assets/TabPane.151b0d64.js","assets/hasIn.41d385a0.js","assets/index.61a3d490.js","assets/Text.b4fa08c4.js","assets/Link.0df5f530.js","assets/Title.50fff1e9.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.9e34f1fa.js","assets/asyncComputed.4cc49353.js","assets/Player.6fed9080.css"])}],g=c({history:f("/"),routes:d,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function b(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await s.init(e)}const n=class{constructor(e){this.config=e}static async init(e){n.instance=new n(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let s=n;a(s,"instance",null);export{s as S,g as a,d as r,b as s};
//# sourceMappingURL=index.81295ba2.js.map
