import{N as b}from"./NavbarControls.86f8b982.js";import{d as _,ey as f,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as r,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.517466a4.js";import{A as C}from"./Text.b4fa08c4.js";import{T as I,A as o}from"./TabPane.151b0d64.js";import{c as A}from"./index.ada15ca9.js";import"./asyncComputed.4cc49353.js";import"./index.81295ba2.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.541da426.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.ba70e99c.js";import"./ant-design.6f3f0026.js";import"./index.79f0c9dc.js";import"./Modal.c37f1dd1.js";import"./storage.a7faa4ce.js";import"./Link.0df5f530.js";import"./index.61a3d490.js";import"./Title.50fff1e9.js";import"./index.60da12cf.js";import"./workspaces.c3f6c735.js";import"./record.00f55d8c.js";import"./pubsub.1c68a664.js";import"./url.f9726388.js";import"./popupNotifcation.4dba9581.js";import"./CircularLoading.c3f6250e.js";import"./icons.18ac3d6d.js";import"./index.d6f709b0.js";import"./hasIn.41d385a0.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="85310c82-17c0-4abb-9dd3-09d995682e78",a._sentryDebugIdIdentifier="sentry-dbid-85310c82-17c0-4abb-9dd3-09d995682e78")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(a){const t=f(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(r(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(b,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(r(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(r(o),{key:"style",tab:"Style"}),e(r(o),{key:"sidebar",tab:"Sidebar"}),e(r(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:l})=>[(c(),x(T(l)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.ff72da93.js.map
