import{S as p}from"./Sidebar.4587c1c5.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.523a9eb4.js";import{G as d,H as l,I as u}from"./icons.18ac3d6d.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.517466a4.js";import{a as z}from"./asyncComputed.4cc49353.js";import"./router.7372192a.js";import"./jwt-decode.esm.74bd4619.js";import"./index.93c4bd99.js";import{O as w}from"./organization.9f4826a6.js";import{B as I}from"./BaseLayout.7babf70d.js";import"./index.1de61334.js";import"./logo.084e5d7c.js";import"./Text.b4fa08c4.js";import"./index.ada15ca9.js";import"./FormItem.ebe02103.js";import"./hasIn.41d385a0.js";import"./storage.a7faa4ce.js";import"./index.c09b1845.js";import"./index.cf4c23b9.js";import"./record.00f55d8c.js";import"./pubsub.1c68a664.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="c802b674-352b-43a5-a9cc-2d325d8a3122",o._sentryDebugIdIdentifier="sentry-dbid-c802b674-352b-43a5-a9cc-2d325d8a3122")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:e}=z(()=>w.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.0ad41468.js.map
