import"./outputWidgets.517466a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="3c6cfaaf-d8d0-4a24-ba04-577f65d7c767",e._sentryDebugIdIdentifier="sentry-dbid-3c6cfaaf-d8d0-4a24-ba04-577f65d7c767")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.f9726388.js.map
