import{d as $,r as h,F as C,b as o,et as g,dm as A,e as m,eB as k,eu as M,t as N,ey as V,ez as z,c,w as l,eA as w,u as i,cs as E,ao as v,bo as I,bd as O,ex as B,f as S,I as D,ev as x,bf as R}from"./outputWidgets.517466a4.js";import{J as F}from"./icons.18ac3d6d.js";import{A as T}from"./index.1de61334.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="b640b3d7-820c-46ac-963b-20cb85f5acec",s._sentryDebugIdIdentifier="sentry-dbid-b640b3d7-820c-46ac-963b-20cb85f5acec")}catch{}})();const q={class:"text"},G=$({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(s){const t=s,d=h(Date.now()),f=()=>{d.value=Date.now()},u=h(null),_=()=>{var r,e,y;const a=(r=u.value)==null?void 0:r.getBoundingClientRect();if(!a)return{};const{x:n,y:p}=a;return d.value,{position:"fixed",top:`${p+((e=t.top)!=null?e:0)}px`,left:`${n+((y=t.left)!=null?y:0)}px`}},b=C(()=>{var a;return t.fixed?_():{left:`${(a=t.left)!=null?a:-14}px`,...t.top?{top:`${t.top}px`}:{}}});return(a,n)=>(o(),g("div",{ref_key:"tooltipBox",ref:u,class:"tooltip-box",onMouseenter:f},[A(a.$slots,"default",{},void 0,!0),m("div",{class:"tooltip",style:M(b.value)},[m("span",q,k(s.text),1)],4)],544))}});const J=N(G,[["__scopeId","data-v-c3a6ca5e"]]),L={style:{"margin-right":"5px"}},P=$({__name:"Sidebar",props:{sections:{}},setup(s){var a;const t=s,d=V(),f=z(),u=h((a=f.name)!=null?a:"forms"),_=C(()=>t.sections.map(n=>({...n,items:n.items.filter(p=>!p.unavailable)}))),b=n=>{n.unavailable||(d.push(n.path),u.value=n.path)};return(n,p)=>(o(),c(i(R),null,{default:l(()=>[(o(!0),g(I,null,w(_.value,r=>(o(),c(i(E),{key:r.name},{title:l(()=>[v(k(r.name),1)]),default:l(()=>[(o(!0),g(I,null,w(r.items,e=>(o(),c(i(O),{key:e.name,role:"button",class:B({"menu-item":!0,active:u.value===e.path,disabled:e.unavailable||r.cloud}),tabindex:"0",onClick:y=>b(e)},{icon:l(()=>[S(D,{class:B({disabled:e.unavailable,active:u.value===e.path}),path:e.icon,width:"20",height:"20"},null,8,["class","path"])]),default:l(()=>[m("span",L,k(e.name),1),e.unavailable?(o(),c(i(T),{key:0},{default:l(()=>[v("SOON")]),_:1})):x("",!0),e.beta?(o(),c(i(T),{key:1},{default:l(()=>[v("BETA")]),_:1})):x("",!0),e.warning?(o(),c(J,{key:2,text:e.warning,fixed:!0,top:18,left:18},{default:l(()=>[S(D,{path:i(F),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):x("",!0)]),_:2},1032,["class","onClick"]))),128))]),_:2},1024))),128))]),_:1}))}});const Q=N(P,[["__scopeId","data-v-38667610"]]);export{Q as S};
//# sourceMappingURL=Sidebar.4587c1c5.js.map
