import{cu as n}from"./outputWidgets.517466a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8633bc50-6b57-4996-84e5-361761c35527",e._sentryDebugIdIdentifier="sentry-dbid-8633bc50-6b57-4996-84e5-361761c35527")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.4dba9581.js.map
