import{t as n,b as s,et as c}from"./outputWidgets.517466a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0c20e280-c86c-4266-b426-18f2dc360511",e._sentryDebugIdIdentifier="sentry-dbid-0c20e280-c86c-4266-b426-18f2dc360511")}catch{}})();const o={},r={class:"organization-settings"};function i(e,t){return s(),c("div",r,"Organization settings")}const f=n(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.70460ce7.js.map
